@@ -8,8 +8,6 @@ require Net::IPAddress::Util;
 require Net::IPAddress::Util::Collection::Tie;
 require Net::IPAddress::Util::Range;
 
-our $RADIX_THRESHOLD;
-
 sub new {
     my $class    = ref($_[0]) ? ref(shift()) : shift;
     my @contents = @_;
@@ -91,7 +89,7 @@ Net::IPAddress::Util::Collection - A collection of Net::IPAddress::Util::Range o
 
 =head1 VERSION
 
-Version 3.027
+Version 3.028
 
 =head1 SYNOPSIS
 
@@ -142,14 +140,5 @@ Stringification for CIDR-style strings.
 
 Stringification for Netmask-style strings.
 
-=head1 GLOBAL VARIABLES
-
-=head2 $Net::IPAddress::Util::Collection::RADIX_THRESHOLD
-
-If set to any defined value (including zero), collections with more than
-$RADIX_THRESHOLD elements will be sorted using the radix sort algorithm,
-which can be faster than Perl's native sort for large data sets. The default
-value is C<undef()>.
-
 =cut
 
